from typing import Literal

TouchAction = Literal[
    'auto',
    'none',
    'pan-x',
    'pan-left',
    'pan-right',
    'pan-y',
    'pan-up',
    'pan-down',
    'pinch-zoom',
    'manipulation',
]
